Retrace
=======

Retrace your steps and try again.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

|PyPI Downloads| |PyPI Version| |Build Status| |Coverage Status|
|Landscale Code Health|

Retrace provides a configurable decorator which allows you to wrap
Python callables and retry them on errors or other specific conditions.

See the documentation at http://d0ugal.github.io/retrace/

.. |PyPI Downloads| image:: https://img.shields.io/pypi/dm/retrace.png
   :target: https://pypi.python.org/pypi/retrace
.. |PyPI Version| image:: https://img.shields.io/pypi/v/retrace.png
   :target: https://pypi.python.org/pypi/retrace
.. |Build Status| image:: https://img.shields.io/travis/d0ugal/retrace/master.png
   :target: https://travis-ci.org/d0ugal/retrace
.. |Coverage Status| image:: http://codecov.io/github/d0ugal/retrace/coverage.svg?branch=master
   :target: http://codecov.io/github/d0ugal/retrace?branch=master
.. |Landscale Code Health| image:: https://landscape.io/github/d0ugal/retrace/master/landscape.svg?style=flat-square
   :target: https://landscape.io/github/d0ugal/retrace/master
